@@ -16,7 +16,19 @@
 gglm <- function(data,
                  theme = ggplot2::theme_gray(),
                  ...) {
-  stopifnot(class(data) %in% c("lm", "glm"))
+  if (!(class(data) %in% c("data.frame", "tbl_df", "tbl"))) {
+    tryCatch({
+      fortify(data)
+    },
+    error = function(cond) {
+      message(
+"It looks like you supplied an object that isn't compatible with `gglm`. 
+Note that for `gglm` to work, there must be an applicable method from `broom` or
+`broom.mixed` to `augment()` the data, or an applicable method from `ggplot2` to
+`fortify()` the data.")
+    })
+  }
+  
   ggplot2::theme_set(theme)
 
   fitted_resid <-
